def km_to_miles(km: float) -> float:
    """
    Convert kilometers to miles.

    Parameters:
    km (float): Distance in kilometers.

    Returns:
    float: Distance in miles.
    """
    return km * 0.621371
